#!/usr/bin/env python
# -*- coding: utf-8 -*-

# file      : pref.py
# project   : basebuildpy
# copyright : (C) 2014 by Claude Bulin
#
# This file is part of basebuildpy project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA


import os
from fconfig import FConfig
import configparser
# init the foreign language
import Language_Init

class Preferences:

	def init(self):
		# Add language support
		_ = Language_Init.Translator(FConfig).lang.gettext
		self._ = _
		self.config = []

	def Preferences_create_file(self):
		print('Preferences_create_file')

		config = configparser.ConfigParser()

		# only for information in file
		config['PACKAGE'] = {
			'Name_Package': FConfig.__PACKAGE__,
			'Package_Version': FConfig.__VERSION__,
			'Package_Author': FConfig.__AUTHOR__,
			'Package_Url': FConfig.__URL__
			}
		# etat fields
		config['STATE'] = {
			'ProjectName': 'ProjectName',
			'ProjectVersion': '0.0.1',
			'ProjectAuthor': 'Author',
			'ProjectDestination': os.getenv("HOME"),
			'_home_': os.getenv("HOME")
			}
		# pos windows main
		config['WIN_MAIN_POS'] = {
			'MAIN_WIN_POS_X' : 10,
			'MAIN_WIN_POS_Y': 10,
			'MAIN_WIN_WIDTH': 500,
			'MAIN_WIN_HEIGHT': 500
			}
		config['LANGUAGES'] = {
			'1' : 'english',
			'2' : 'french',
			'3' : 'german',
			'4' : 'italian',
			'5' : 'spanish'
			}
		with open(os.path.join(FConfig.CONFIGFILE, "basebuildpy.config"), 'w') as configfile:
			config.write(configfile)

	def Preferences_read_file(self):
		path = os.path.join(FConfig.CONFIGFILE, "basebuildpy.config")
		if not os.path.isfile( path ):
			print('create [ ' + path + ' ]')
			self.Preferences_create_file()

		print('Preferences_read_file')

		self.config = configparser.ConfigParser()
		self.config.read(os.path.join(FConfig.CONFIGFILE, "basebuildpy.config"))

		for key in self.config:
			print(' '*4 + key)
			for k in self.config[ key ]:
				str_k = "        " + k
				while len(str_k) < 30:
					str_k = str_k + " "
				str_k = str_k + self.config[ key ][ k ]
				print( str_k )

	def Preferences_save_file(self):
		print('Preferences_save_file')
		with open(os.path.join(FConfig.CONFIGFILE, "basebuildpy.config"), 'w') as configfile:
			self.config.write(configfile)

	def Preferences_get_win_width(self):
		if 'WIN_MAIN_POS' in self.config and 'MAIN_WIN_WIDTH' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'MAIN_WIN_WIDTH' ] )
		else:
			return 600

	def Preferences_get_win_height(self):
		if 'WIN_MAIN_POS' in self.config and 'MAIN_WIN_HEIGHT' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'MAIN_WIN_HEIGHT' ] )
		else:
			return 450

	def Preferences_get_main_win_pos_x(self):
		if 'WIN_MAIN_POS' in self.config and 'MAIN_WIN_POS_X' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'MAIN_WIN_POS_X' ] )
		else:
			return 10

	def Preferences_get_main_win_pos_y(self):
		if 'WIN_MAIN_POS' in self.config and 'MAIN_WIN_POS_Y' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'MAIN_WIN_POS_Y' ] )
		else:
			return 10

	def Preferences_get_home(self):
		# if 'HOME' in os.environ:
		# 	home = os.environ['HOME']
		return self.config[ 'STATE' ][ '_home_' ]

	def Preferences_get_ProjectName(self):
		if 'STATE' in self.config and 'ProjectName' in self.config[ 'STATE' ]:
			return self.config[ 'STATE' ][ 'ProjectName' ]
		else:
			return ""
	def Preferences_get_ProjectVersion(self):
		if 'STATE' in self.config and 'ProjectVersion' in self.config[ 'STATE' ]:
			return self.config[ 'STATE' ][ 'ProjectVersion' ]
		else:
			return ""
	def Preferences_get_ProjectAuthor(self):
		if 'STATE' in self.config and 'ProjectAuthor' in self.config[ 'STATE' ]:
			return self.config[ 'STATE' ][ 'ProjectAuthor' ]
		else:
			return ""
	def Preferences_get_form_ProjectDestination(self):
		if 'STATE' in self.config and 'ProjectDestination' in self.config[ 'STATE' ]:
			return self.config[ 'STATE' ][ 'ProjectDestination' ]
		else:
			return self.config[ 'STATE' ][ '_home_' ]

	def Preferences_get_LANGUAGES(self):
		ListUpdateLangs = []
		if 'LANGUAGES' in self.config:
			for l in self.config[ 'LANGUAGES' ]:
				# print("Lang = ", l )
				# print("     = ", self.config[ 'LANGUAGES' ][ l ] )
				ListUpdateLangs.append( self.config[ 'LANGUAGES' ][ l ] )
		return ListUpdateLangs

	def Preferences_save_op(self,
			form_ProjectName,
			form_ProjectVersion,
			form_ProjectAuthor,
			form_ProjectDestination,
			form_ListUpdateLangs,
			x, y, w, h):
		print('Preferences_save_op')

		self.config.clear()
		self.config = configparser.ConfigParser()

	   # only for information in file
		self.config['PACKAGE'] = {
			'Name_Package': FConfig.__PACKAGE__,
			'Package_Version': FConfig.__VERSION__,
			'Package_Author': FConfig.__AUTHOR__,
			'Package_Url': FConfig.__URL__
			}
		# etat fields
		self.config['STATE'] = {
			'ProjectName': form_ProjectName,
			'ProjectVersion': form_ProjectVersion,
			'ProjectAuthor': form_ProjectAuthor,
			'ProjectDestination': form_ProjectDestination,
			'_home_': os.getenv("HOME")
			}
		# pos windows main
		self.config['WIN_MAIN_POS'] = {
			'MAIN_WIN_POS_X' : x,
			'MAIN_WIN_POS_Y': y,
			'MAIN_WIN_WIDTH': w,
			'MAIN_WIN_HEIGHT': h
			}

		if form_ListUpdateLangs:
			self.config.add_section('LANGUAGES')
			NumDummy = 1
			for item in form_ListUpdateLangs:
				self.config.set('LANGUAGES', str(NumDummy), item[1])
				NumDummy += 1

		with open(os.path.join(FConfig.CONFIGFILE, "basebuildpy.config"), 'w') as configfile:
			self.config.write(configfile)

		for key in self.config:
			print(' '*4 + key)
			for k in self.config[ key ]:
				str_k = "        " + k
				while len(str_k) < 30:
					str_k = str_k + " "
				str_k = str_k + self.config[ key ][ k ]
				print( str_k )

if __name__ == "__main__":
	clg = Preferences()
	clg.Preferences_create_file()
	clg.Preferences_read_file()
